from setuptools import setup, find_packages
 
setup(
    name = "laix",
    version = "0.0.0",
    keywords = ('laix'),
    description = 'a simple egg',
    license = 'MIT License',
    url = 'https://github.com/liluo',
    author = 'liluo',
    author_email = 'liluorz@gmail.com',
    packages = find_packages(),
)
